@@ -186,7 +186,7 @@ def node_factory(edge_model, children_null=True, base_model=models.Model):
                 children__in=self.children.all()
             ).distinct()
 
-        def path_raw(self, ending_node, directional=True, max_depth=20, **kwargs):
+        def path_raw(self, ending_node, directional=True, **kwargs):
             """
             Returns shortest path from self to ending node, optionally in either
             direction. The resulting RawQueryset is sorted from root-side, toward
@@ -374,6 +374,20 @@ def node_factory(edge_model, children_null=True, base_model=models.Model):
             """
             return self.ancestors_edges() | self.descendants_edges()
 
+        def parent_edges(self):
+            return edge_model.objects.filter(
+                child__in=[
+                    self,
+                ],
+            )
+
+        def child_edges(self):
+            return edge_model.objects.filter(
+                parent__in=[
+                    self,
+                ],
+            )
+
         @staticmethod
         def circular_checker(parent, child):
             if child in parent.self_and_ancestors():
